import os
import requests
import tensorflow as tf

class Retriever:

    def get_h5_model(self, modelName, cid):

        # IPFS API endpoint
        api_endpoint = f"https://{cid}.ipfs.w3s.link/ipfs/{cid}/{modelName}.h5"

        try:
            # Get the current directory
            current_dir = os.getcwd()

            # Construct the file path in the 'models' directory
            models_dir = os.path.join(current_dir, "models")
            os.makedirs(models_dir, exist_ok=True)

            # Construct the file path for the model
            file_path = os.path.join(models_dir, f"{modelName}.h5")

            # Fetch the file from IPFS
            response = requests.get(api_endpoint)
            if response.status_code == 200:
                # Write the response content to the file
                with open(file_path, "wb") as f:
                    f.write(response.content)
                
                print("File fetched successfully from IPFS and saved at:", file_path)

                # Load the model and return it
                loaded_model = tf.keras.models.load_model(file_path)
                return loaded_model
            else:
                print("Error fetching file from IPFS. Status code:", response.status_code)
                return None
        except Exception as e:
            print("Error:", e)
            return None




import setuptools

setuptools.setup(
    name="ai3",
    version="0.0.0",
    author="Carlos Linares",
    author_email="oddskid@gmail.com",
    url="https://github.com/carlosarturoceron/ai3",
    packages=setuptools.find_packages(),
    install_requires = [
        "requests",
        "tensorflow"
    ],
    python_requires =">=3.8",
    include_package_data=True
)


from .utils.load import Retriever

class spamDetection:

    @staticmethod
    def load():
        storage = Retriever()
        # Example CID for the model on IPFS
        model_name = "spamDetection"
        cid = "bafybeibpfdw6stsf3leqj3a3fvwsx7bzjahifbnuy2adofhkfif7nwmyrq"
        # Example transaction ID for the model on Arweave
        return storage.get_h5_model(model_name, cid)

class imageNet:

    @staticmethod
    def load():
        storage = Retriever()
        # Example CID for the model on IPFS
        model_name = "imageNet"
        cid = "bafybeif6torjb3t7wha56go3a6yullryafdctg2ipz5rxi5azjmgolx23e"
        # Example transaction ID for the model on Arweave
        return storage.get_h5_model(model_name, cid)
